#! /usr/bin/bash
# Launcher script for the docker image of the ces slurm simulator
#
# This script is meant to ease the launching of the simulator. 
# it encapsulates the bulky docker commands and handles internal
# logic
#
# BSC-CNS - Earth Sciences
# Manuel Giménez de Castro Marciani
# 2023

function check_path {
	if [[ -d $1 ]]; then
		echo  "launcher.sh: path $1 does not exist"
		exit 1
	fi
}

# mandatory arguments
SWF_FILE_PATH=$1
OUT_TRACE_FILE=$2
SIMULATED_SECONDS=$3

# optional, will make the simulator faster since it won't need to build users
USERS_FILE_PATH=$4
DB_DUMP_PATH=$5

# checking mandatory params

if [[ ! $SWF_FILE_PATH ]]; then
	echo "launcher.sh: you need to provide a SWF file"
	exit 1
fi

if [[ ! $OUT_TRACE_FILE ]]; then
	echo "launcher.sh: you need to provide an .trace output file"
	exit 1
fi

if [[ ! $SIMULATED_SECONDS ]]; then
	echo "launcher.sh: you need to provide the total number of seconds to be simulated"
	exit 1
fi

check_path $SWF_FILE_PATH
check_path $OUT_TRACE_FILE

# we check if the image has been built 
if [[ ! $(docker images | grep "mgimenez/docker-ubuntu-ces-slurm-sim" | grep "latest") ]]; then
	echo "launcher.sh: image does not exist. Building it now."
	docker build . --tag mgimenez/docker-ubuntu-ces-slurm-sim:latest
fi

if [[ $DB_DUMP_PATH ]]; then
	check_path $DB_DUMP_PATH

	if [[ ! $USERS_FILE_PATH ]]; then
		echo "launcher.sh: if you provide a dumped sql database, you need also to provide a users.sim file"
		exit 1
	else
		check_path $USERS_FILE_PATH

		docker run --rm -h localhost \
		--mount type=bind,source=$SWF_FILE_PATH,target=/opt/ces_slurm_simulator_tools/workloads/workload.swf \
		--mount type=bind,source=$OUT_TRACE_FILE,target=/opt/ces_slurm_simulator_tools/simulation/TRACES/out.trace \
		--mount type=bind,source=$USERS_FILE_PATH,target=/opt/ces_slurm_simulator_tools/install/slurm_conf/users.sim \
		--mount type=bind,source=$DB_DUMP_PATH,target=/opt/ces_slurm_simulator_tools/slurm_sacct_db.sql \
		mgimenez/docker-ubuntu-ces-slurm-sim:latest --not-create-users --end-time $SIMULATED_SECONDS
	fi
else
	if [[ $USERS_FILE_PATH ]]; then
		echo "launcher.sh: ignoring users.sim path, since there is no database dump file."
	fi
	
	docker run --rm -h localhost \
	--mount type=bind,source=$SWF_FILE_PATH,target=/opt/ces_slurm_simulator_tools/workloads/workload.swf \
	--mount type=bind,source=$OUT_TRACE_FILE,target=/opt/ces_slurm_simulator_tools/simulation/TRACES/out.trace \
	mgimenez/docker-ubuntu-ces-slurm-sim:latest --end-time $SIMULATED_SECONDS
fi	


